@@ -27,7 +27,7 @@ def get_browser_navigate_tool_definition(provider="claude") -> Dict[str, Any]:
 
     if provider == "claude":
         return {
-            "name": "browser_navigate",
+            "name": "navigate_url",
             "description": tool_description,
             "input_schema": {
                 "type": "object",
@@ -39,7 +39,7 @@ def get_browser_navigate_tool_definition(provider="claude") -> Dict[str, Any]:
         return {
             "type": "function",
             "function": {
-                "name": "browser_navigate",
+                "name": "navigate_url",
                 "description": tool_description,
                 "parameters": {
                     "type": "object",
@@ -52,20 +52,18 @@ def get_browser_navigate_tool_definition(provider="claude") -> Dict[str, Any]:
 
 def get_browser_click_tool_definition(provider="claude") -> Dict[str, Any]:
     """Get tool definition for browser element clicking."""
-    tool_description = (
-        "Click an element using its UUID. Get UUIDs from browser_get_content first."
-    )
+    tool_description = "Click an element using its UUID. Get UUIDs from get_browser_content tool result first."
     tool_arguments = {
         "element_uuid": {
             "type": "string",
-            "description": "UUID identifier from browser_get_content clickable elements table.",
+            "description": "UUID identifier from get_browser_content tool result clickable elements table.",
         }
     }
     tool_required = ["element_uuid"]
 
     if provider == "claude":
         return {
-            "name": "browser_click",
+            "name": "click_browser_element",
             "description": tool_description,
             "input_schema": {
                 "type": "object",
@@ -77,7 +75,7 @@ def get_browser_click_tool_definition(provider="claude") -> Dict[str, Any]:
         return {
             "type": "function",
             "function": {
-                "name": "browser_click",
+                "name": "click_browser_element",
                 "description": tool_description,
                 "parameters": {
                     "type": "object",
@@ -109,13 +107,14 @@ def get_browser_scroll_tool_definition(provider="claude") -> Dict[str, Any]:
         "element_uuid": {
             "type": "string",
             "description": "Optional UUID for specific element to scroll. Scrolls document if not provided.",
+            "default": "document",
         },
     }
-    tool_required = ["direction"]
+    tool_required = ["direction", "element_uuid"]
 
     if provider == "claude":
         return {
-            "name": "browser_scroll",
+            "name": "scroll_browser",
             "description": tool_description,
             "input_schema": {
                 "type": "object",
@@ -127,7 +126,7 @@ def get_browser_scroll_tool_definition(provider="claude") -> Dict[str, Any]:
         return {
             "type": "function",
             "function": {
-                "name": "browser_scroll",
+                "name": "scroll_browser",
                 "description": tool_description,
                 "parameters": {
                     "type": "object",
@@ -142,14 +141,14 @@ def get_browser_get_content_tool_definition(provider="claude") -> Dict[str, Any]
     """Get tool definition for browser content extraction."""
     tool_description = (
         "Extract page content as markdown with tables of clickable, input, and scrollable elements. UUIDs reset on each call."
-        "browser_get_content result is UNIQUE in whole conversation. Remember to summarize important information before calling again."
+        "get_browser_content tool's result is UNIQUE in whole conversation. Remember to summarize important information before calling again."
     )
     tool_arguments = {}
     tool_required = []
 
     if provider == "claude":
         return {
-            "name": "browser_get_content",
+            "name": "get_browser_content",
             "description": tool_description,
             "input_schema": {
                 "type": "object",
@@ -161,7 +160,7 @@ def get_browser_get_content_tool_definition(provider="claude") -> Dict[str, Any]
         return {
             "type": "function",
             "function": {
-                "name": "browser_get_content",
+                "name": "get_browser_content",
                 "description": tool_description,
                 "parameters": {
                     "type": "object",
@@ -196,7 +195,7 @@ def get_browser_get_content_tool_handler(
                 tool_result.append(context_image.get("screenshot", {}))
             return tool_result
         else:
-            raise RuntimeError(f"❌ Content extraction failed: {result['error']}")
+            raise RuntimeError(f"Content extraction failed: {result['error']}")
 
     return handle_browser_get_content
 
@@ -221,9 +220,9 @@ def get_browser_navigate_tool_handler(
                 if result.get("profile")
                 else ""
             )
-            return f"✅ {result.get('message', 'Success')}. Use `browser_get_content` to read the url content.\nCurrent URL: {result.get('current_url', 'Unknown')}{profile_info}"
+            return f"{result.get('message', 'Success')}. Call `get_browser_content` tool to read the url content.\nCurrent URL: {result.get('current_url', 'Unknown')}{profile_info}"
         else:
-            raise RuntimeError(f"❌ Navigation failed: {result['error']}")
+            raise RuntimeError(f"Navigation failed: {result['error']}")
 
     return handle_browser_navigate
 
@@ -241,16 +240,15 @@ def get_browser_click_tool_handler(
 
         result = browser_service.click_element(element_uuid)
 
-        diff_summary = _get_content_delta_changes(browser_service)
-
         if result.get("success", True):
+            diff_summary = _get_content_delta_changes(browser_service)
             return (
-                f"✅ {result.get('message', 'Success')}. Use `browser_get_content` to get the updated content.\n"
+                f"{result.get('message', 'Success')}. Call `get_browser_content` tool to get the updated content.\n"
                 f"UUID: {element_uuid}\nClickedElement: {result.get('elementInfo', {}).get('text', 'Unknown')}.\n"
                 f"Content delta changes:\n{diff_summary}"
             )
         else:
-            return f"❌ Click failed: {result['error']}\nUUID: {element_uuid}.\nUse `browser_get_content` to get the updated UUID"
+            return f"Click failed: {result['error']}\nUUID: {element_uuid}.\nCall `get_browser_content` tool to get the updated UUID"
 
     return handle_browser_click
 
@@ -273,24 +271,26 @@ def get_browser_scroll_tool_handler(
                 "Error: Invalid scroll direction. Use 'up', 'down', 'left', or 'right'."
             )
 
-        result = browser_service.scroll_page(direction, amount, element_uuid)
+        result = browser_service.scroll_page(
+            direction, amount, element_uuid if element_uuid != "document" else None
+        )
 
         if result.get("success", True):
-            return f"✅ {result.get('message', 'Success')}, Use `browser_get_content` to get the updated content."
+            return f"{result.get('message', 'Success')}, Call `get_browser_content` tool to get the updated content."
         else:
             uuid_info = f"\nUUID: {element_uuid}" if element_uuid else ""
-            raise RuntimeError(f"❌ Scroll failed: {result['error']}{uuid_info}")
+            raise RuntimeError(f"Scroll failed: {result['error']}{uuid_info}")
 
     return handle_browser_scroll
 
 
 def get_browser_input_tool_definition(provider="claude") -> Dict[str, Any]:
     """Get tool definition for browser input."""
-    tool_description = "Input data into form fields using UUID. Get UUIDs from browser_get_content first."
+    tool_description = "Input data into form fields using UUID. Get UUIDs from get_browser_content tool first."
     tool_arguments = {
         "element_uuid": {
             "type": "string",
-            "description": "UUID identifier from browser_get_content input elements table.",
+            "description": "UUID identifier from get_browser_content tool result's input elements table.",
         },
         "value": {
             "type": "string",
@@ -301,7 +301,7 @@ def get_browser_input_tool_definition(provider="claude") -> Dict[str, Any]:
 
     if provider == "claude":
         return {
-            "name": "browser_input",
+            "name": "input_browser_field",
             "description": tool_description,
             "input_schema": {
                 "type": "object",
@@ -313,7 +313,7 @@ def get_browser_input_tool_definition(provider="claude") -> Dict[str, Any]:
         return {
             "type": "function",
             "function": {
-                "name": "browser_input",
+                "name": "input_browser_field",
                 "description": tool_description,
                 "parameters": {
                     "type": "object",
@@ -340,13 +340,13 @@ def get_browser_input_tool_handler(
             return "Error: No value provided for input."
 
         result = browser_service.input_data(element_uuid, str(value))
-        diff_summary = _get_content_delta_changes(browser_service)
 
         if result.get("success", True):
-            return f"✅ {result.get('message', 'Success')}\nUUID: {element_uuid}\nValue: {value}\nContent delta changes:\n{diff_summary}"
+            diff_summary = _get_content_delta_changes(browser_service)
+            return f"{result.get('message', 'Success')}\nUUID: {element_uuid}\nValue: {value}\nContent delta changes:\n{diff_summary}"
         else:
             raise RuntimeError(
-                f"❌ Input failed: {result['error']}\nUUID: {element_uuid}\nValue: {value}.\n Use `browser_get_content` to get updated UUID."
+                f"Input failed: {result['error']}\nUUID: {element_uuid}\nValue: {value}.\n Call `get_browser_content` tool to get updated UUID."
             )
 
     return handle_browser_input
@@ -367,7 +367,7 @@ def get_browser_get_elements_by_text_tool_definition(
 
     if provider == "claude":
         return {
-            "name": "browser_get_elements_by_text",
+            "name": "get_browser_elements_by_text",
             "description": tool_description,
             "input_schema": {
                 "type": "object",
@@ -379,7 +379,7 @@ def get_browser_get_elements_by_text_tool_definition(
         return {
             "type": "function",
             "function": {
-                "name": "browser_get_elements_by_text",
+                "name": "get_browser_elements_by_text",
                 "description": tool_description,
                 "parameters": {
                     "type": "object",
@@ -405,16 +405,15 @@ def get_browser_get_elements_by_text_tool_handler(
         if result.get("success", False):
             elements_found = result.get("elements_found", 0)
             if elements_found == 0:
-                return f"✅ No elements found containing text: '{text}'"
+                return f"No elements found containing text: '{text}'"
 
             content = result.get("content", "")
             return (
-                f"✅ Found {elements_found} elements containing text: '{text}'\n"
-                + content
+                f"Found {elements_found} elements containing text: '{text}'\n" + content
             )
         else:
             raise RuntimeError(
-                f"❌ Search failed: {result.get('error', 'Unknown error')}\nSearch text: '{text}'"
+                f"Search failed: {result.get('error', 'Unknown error')}\nSearch text: '{text}'"
             )
 
     return handle_browser_get_elements_by_text
@@ -422,7 +421,7 @@ def get_browser_get_elements_by_text_tool_handler(
 
 def get_browser_capture_screenshot_tool_definition(provider="claude") -> Dict[str, Any]:
     """Get tool definition for browser screenshot capture."""
-    tool_description = "Capture page screenshot as base64 image data. Supports different formats and full page capture."
+    tool_description = "Capture page screenshot as base64 image data with colored boxes and UUID labels drawn over all identified elements. Supports different formats and full page capture."
     tool_arguments = {
         "format": {
             "type": "string",
@@ -446,7 +445,7 @@ def get_browser_capture_screenshot_tool_definition(provider="claude") -> Dict[st
 
     if provider == "claude":
         return {
-            "name": "browser_capture_screenshot",
+            "name": "capture_browser_screenshot",
             "description": tool_description,
             "input_schema": {
                 "type": "object",
@@ -458,7 +457,7 @@ def get_browser_capture_screenshot_tool_definition(provider="claude") -> Dict[st
         return {
             "type": "function",
             "function": {
-                "name": "browser_capture_screenshot",
+                "name": "capture_browser_screenshot",
                 "description": tool_description,
                 "parameters": {
                     "type": "object",
@@ -500,7 +499,7 @@ def get_browser_capture_screenshot_tool_handler(
             return [screenshot_data]
         else:
             raise RuntimeError(
-                f"❌ Screenshot capture failed: {result.get('error', 'Unknown error')}"
+                f"Screenshot capture failed: {result.get('error', 'Unknown error')}"
             )
 
     return handle_browser_capture_screenshot
@@ -572,7 +571,7 @@ def get_browser_send_key_tool_definition(provider="claude") -> Dict[str, Any]:
 
     if provider == "claude":
         return {
-            "name": "browser_send_key",
+            "name": "send_browser_key",
             "description": tool_description,
             "input_schema": {
                 "type": "object",
@@ -584,7 +583,7 @@ def get_browser_send_key_tool_definition(provider="claude") -> Dict[str, Any]:
         return {
             "type": "function",
             "function": {
-                "name": "browser_send_key",
+                "name": "send_browser_key",
                 "description": tool_description,
                 "parameters": {
                     "type": "object",
@@ -617,13 +616,13 @@ def get_browser_send_key_tool_handler(
                 else ""
             )
             diff_summary = _get_content_delta_changes(browser_service)
-            success_msg = f"✅ {result.get('message', 'Success')}. {key_info}\nContent delta changes:\n{diff_summary}"
+            success_msg = f"{result.get('message', 'Success')}. {key_info}\nContent delta changes:\n{diff_summary}"
             if modifiers_info:
                 success_msg += f". {modifiers_info}"
             return success_msg
         else:
             raise RuntimeError(
-                f"❌ Key send failed: {result.get('error', 'Unknown error')}"
+                f"Key send failed: {result.get('error', 'Unknown error')}"
             )
 
     return handle_browser_send_key
