@@ -105,8 +105,14 @@ class CommandProcessor:
         asssistant_messages_iterator = reversed(
             [
                 msg
-                for msg in self.message_handler.streamline_messages
+                for i, msg in enumerate(self.message_handler.streamline_messages)
                 if msg.get("role") == "assistant"
+                and (
+                    self.message_handler.streamline_messages[i + 1].get("role")
+                    == "user"
+                    if i + 1 < len(self.message_handler.streamline_messages)
+                    else True
+                )
             ]
         )
         latest_assistant_blk = None
@@ -376,10 +382,26 @@ class CommandProcessor:
             self.message_handler.last_assisstant_response_idx = len(
                 self.message_handler.streamline_messages
             )
+            if isinstance(selected_message.get("content"), list):
+                selected_content = next(
+                    (
+                        c.get("text", "")
+                        for c in selected_message.get("content", [])
+                        if c.get("type", "") == "text"
+                    ),
+                    "",
+                )
+
+            else:
+                selected_content = selected_message.get("content", "")
 
             self.message_handler._notify(
                 "jump_performed",
-                {"turn_number": turn_number, "preview": selected_turn.get_preview(100)},
+                {
+                    "turn_number": turn_number,
+                    "preview": selected_turn.get_preview(100),
+                    "message": selected_content,
+                },
             )
 
             return True
