@@ -6,6 +6,7 @@ Refactored to use separate modules for different responsibilities.
 from __future__ import annotations
 import asyncio
 import time
+import sys
 import signal
 from typing import Any
 from rich.console import Console
@@ -17,9 +18,11 @@ from .utils import agent_evaluation_remove
 
 from .constants import (
     RICH_STYLE_GREEN,
+    RICH_STYLE_BLUE,
     RICH_STYLE_YELLOW,
     RICH_STYLE_GREEN_BOLD,
     RICH_STYLE_YELLOW_BOLD,
+    PROMPT_CHAR,
 )
 
 from typing import TYPE_CHECKING
@@ -34,7 +37,7 @@ class ConsoleUI(Observer):
     to receive updates from the MessageHandler.
     """
 
-    def __init__(self, message_handler: MessageHandler):
+    def __init__(self, message_handler: MessageHandler, swap_enter: bool = False):
         """
         Initialize the ConsoleUI.
 
@@ -55,18 +58,16 @@ class ConsoleUI(Observer):
         self.message_handler.attach(self)
 
         self._is_resizing = False
-        signal.signal(signal.SIGWINCH, self._handle_terminal_resize)
 
         self.console = Console()
         self._last_ctrl_c_time = 0
-        self.latest_assistant_response = ""
         self.session_cost = 0.0
 
         # Initialize component handlers
         self.display_handlers = DisplayHandlers(self)
         self.tool_display = ToolDisplayHandlers(self)
         self.ui_effects = UIEffects(self)
-        self.input_handler = InputHandler(self)
+        self.input_handler = InputHandler(self, swap_enter=swap_enter)
         self.confirmation_handler = ConfirmationHandler(self)
         self.conversation_handler = ConversationHandler(self)
         self.command_handlers = CommandHandlers(self)
@@ -88,7 +89,7 @@ class ConsoleUI(Observer):
                 data
             )  # data is the thinking chunk
         elif event == "user_message_created":
-            self.console.print("\n")
+            pass
         elif event == "response_chunk":
             _, assistant_response = data
             if (
@@ -131,7 +132,6 @@ class ConsoleUI(Observer):
         elif event == "response_completed" or event == "assistant_message_added":
             data = agent_evaluation_remove(data)
             self.ui_effects.finish_response(data)  # data is the complete response
-            self.latest_assistant_response = data
         elif event == "error":
             self.display_handlers.display_error(
                 data
@@ -142,11 +142,6 @@ class ConsoleUI(Observer):
                 Text("🎮 Chat history cleared.", style=RICH_STYLE_YELLOW_BOLD)
             )
             self.display_handlers.clear_files()
-        elif event == "exit_requested":
-            self.display_handlers.display_message(
-                Text("🎮 Ending chat session. Goodbye!", style=RICH_STYLE_YELLOW_BOLD)
-            )
-            raise SystemExit(0)
         elif event == "copy_requested":
             self.copy_to_clipboard(data)  # data is the text to copy
         elif event == "debug_requested":
@@ -197,6 +192,7 @@ class ConsoleUI(Observer):
 
             self.display_handlers.display_message(jump_text)
             self.display_handlers.display_message(preview_text)
+            self.input_handler.set_current_buffer(data["message"])
         elif event == "thinking_completed":
             self.display_handlers.display_divider()
         elif event == "file_processing":
@@ -207,12 +203,14 @@ class ConsoleUI(Observer):
         elif event == "consolidation_completed":
             self.display_handlers.display_consolidation_result(data)
             self.display_handlers.display_loaded_conversation(
-                self.message_handler.streamline_messages, self.message_handler
+                self.message_handler.streamline_messages,
+                self.message_handler.agent.name,
             )
 
         elif event == "unconsolidation_completed":
             self.display_handlers.display_loaded_conversation(
-                self.message_handler.streamline_messages, self.message_handler
+                self.message_handler.streamline_messages,
+                self.message_handler.agent.name,
             )
         elif event == "conversations_listed":
             self.display_handlers.display_conversations(
@@ -291,19 +289,33 @@ class ConsoleUI(Observer):
         import os
         import time
 
-        if self.input_handler.is_message_processing and self._is_resizing:
+        if self.input_handler.is_message_processing or self._is_resizing:
             return  # Ignore resize during message processing
         self._is_resizing = True
-        time.sleep(0.3)  # brief pause to allow resize to complete
+        time.sleep(0.5)  # brief pause to allow resize to complete
         os.system("cls" if os.name == "nt" else "printf '\033c'")
         self.display_handlers.display_loaded_conversation(
-            self.message_handler.streamline_messages, self.message_handler
+            self.message_handler.streamline_messages, self.message_handler.agent.name
         )
         self.display_handlers.print_prompt_prefix(
             self.message_handler.agent.name,
             self.message_handler.agent.get_model(),
             self.message_handler.tool_manager.get_effective_yolo_mode(),
         )
+
+        self.display_handlers.print_divider("👤 YOU: ", with_time=True)
+
+        prompt = Text(
+            PROMPT_CHAR,
+            style=RICH_STYLE_BLUE,
+        )
+        if self.input_handler._current_prompt_session:
+            prompt.append(
+                self.input_handler._current_prompt_session.default_buffer.text,
+                style="white",
+            )
+
+        self.console.print(prompt, end="")
         self._is_resizing = False
 
     def start_streaming_response(self, agent_name: str):
@@ -410,13 +422,29 @@ class ConsoleUI(Observer):
 
         try:
             while True:
+                if sys.platform != "win32":
+                    if (
+                        not signal.getsignal(signal.SIGWINCH)
+                        or signal.getsignal(signal.SIGWINCH) == signal.SIG_DFL
+                    ):
+                        signal.signal(signal.SIGWINCH, self._handle_terminal_resize)
                 try:
                     # Get user input (now in separate thread)
+                    self.input_handler.is_message_processing = False
                     self.stop_loading_animation()  # Stop if any
                     user_input = self.get_user_input()
 
                     # Handle list command directly
-                    if user_input.strip() == "/list":
+                    if user_input.strip() in ["/exit", "/quit"]:
+                        self.display_handlers.display_message(
+                            Text(
+                                "🎮 Ending chat session. Goodbye!",
+                                style=RICH_STYLE_YELLOW_BOLD,
+                            )
+                        )
+                        self.input_handler.stop()
+                        raise SystemExit(0)
+                    elif user_input.strip() == "/list":
                         conversations = self.message_handler.list_conversations()
                         self.conversation_handler.update_cached_conversations(
                             conversations
@@ -518,8 +546,63 @@ class ConsoleUI(Observer):
                         self.command_handlers.handle_edit_config_command()
                         continue
 
+                    # Handle list_behaviors command
+                    elif user_input.strip() == "/list_behaviors":
+                        self.command_handlers.handle_list_behaviors_command()
+                        continue
+
+                    # Handle update_behavior command
+                    elif user_input.strip().startswith("/update_behavior "):
+                        args = user_input.strip()[17:].strip()
+                        if args:
+                            parts = args.split(maxsplit=2)
+                            if len(parts) == 3:
+                                scope, behavior_id, behavior_text = parts
+                                self.command_handlers.handle_update_behavior_command(
+                                    behavior_id, behavior_text, scope
+                                )
+                            else:
+                                self.console.print(
+                                    Text(
+                                        "Usage: /update_behavior <scope> <id> <behavior_text>\n"
+                                        "Example: /update_behavior project my_behavior_id when user asks about X, do provide detailed examples",
+                                        style=RICH_STYLE_YELLOW,
+                                    )
+                                )
+                        else:
+                            self.console.print(
+                                Text(
+                                    "Usage: /update_behavior <scope> <id> <behavior_text>\n"
+                                    "Example: /update_behavior project my_behavior_id when user asks about X, do provide detailed examples",
+                                    style=RICH_STYLE_YELLOW,
+                                )
+                            )
+                        continue
+
+                    # Handle delete_behavior command
+                    elif user_input.strip().startswith("/delete_behavior "):
+                        args = user_input.strip()[17:].strip()
+                        parts = args.split(maxsplit=1)
+                        if len(parts) == 2:
+                            scope, behavior_id = parts
+                            self.command_handlers.handle_delete_behavior_command(
+                                behavior_id, scope
+                            )
+                        else:
+                            self.console.print(
+                                Text(
+                                    "Usage: /delete_behavior <scope> <id>\n"
+                                    "Example: /delete_behavior <scope> my_behavior_id",
+                                    style=RICH_STYLE_YELLOW,
+                                )
+                            )
+                        continue
+
+                    elif user_input.startswith("/voice"):
+                        self.input_handler._stop_input_thread()
+                        self.voice_recording = True
                     # Start loading animation while waiting for response
-                    if (
+                    elif (
                         not user_input.startswith("/")
                         or user_input.startswith("/file ")
                         or user_input.startswith("/consolidate ")
@@ -529,10 +612,6 @@ class ConsoleUI(Observer):
                     ):
                         self.start_loading_animation()
 
-                    if user_input.startswith("/voice"):
-                        self.input_handler._stop_input_thread()
-                        self.voice_recording = True
-
                     # Process user input and commands
                     should_exit, was_cleared = asyncio.run(
                         self.message_handler.process_user_input(user_input)
@@ -555,13 +634,12 @@ class ConsoleUI(Observer):
                     if not self.message_handler.agent.history:
                         continue
 
-                    self.input_handler.is_message_processing = True
                     # Get assistant response
                     assistant_response, input_tokens, output_tokens = asyncio.run(
                         self.message_handler.get_assistant_response()
                     )
 
-                    self.input_handler.is_message_processing = False
+                    self._is_resizing = False
 
                     # Ensure loading animation is stopped
                     self.stop_loading_animation()
@@ -577,7 +655,6 @@ class ConsoleUI(Observer):
                         )
                 except KeyboardInterrupt:
                     self._handle_keyboard_interrupt()
-                    self.input_handler.is_message_processing = False
                     continue  # Continue the loop instead of breaking
         finally:
             # Clean up input thread when exiting
