@@ -10,6 +10,7 @@ import re
 from datetime import datetime
 from typing import Dict, Any, List
 from rich.console import Group
+from rich.box import HORIZONTALS, SIMPLE, SQUARE
 from rich.markdown import Markdown
 from rich.text import Text
 from rich.panel import Panel
@@ -22,6 +23,7 @@ from .constants import (
     RICH_STYLE_GRAY,
     RICH_STYLE_YELLOW_BOLD,
     RICH_STYLE_GREEN_BOLD,
+    RICH_STYLE_BLUE_BOLD,
     RICH_STYLE_FILE_ACCENT_BOLD,
     RICH_STYLE_WHITE,
     CODE_THEME,
@@ -70,16 +72,17 @@ class DisplayHandlers:
 
     def display_message(self, message: Text):
         """Display a generic message."""
-        self.console.print(message)
+        self.console.print(Panel(message, box=SIMPLE))
 
     def display_user_message(self, message: str):
         header = Text(
             "👤 YOU:",
-            style=RICH_STYLE_GREEN_BOLD,
+            style=RICH_STYLE_BLUE_BOLD,
         )
         user_panel = Panel(
             Text(message),
             title=header,
+            box=HORIZONTALS,
             title_align="left",
             border_style=RICH_STYLE_BLUE,
         )
@@ -93,6 +96,7 @@ class DisplayHandlers:
         assistant_panel = Panel(
             Markdown(message, code_theme=CODE_THEME),
             title=header,
+            box=HORIZONTALS,
             title_align="left",
             border_style=RICH_STYLE_GREEN,
         )
@@ -102,6 +106,21 @@ class DisplayHandlers:
         """Display a divider line."""
         pass
 
+    def print_divider(self, title="", with_time=False):
+        """Display a divider line."""
+        title_length = len(title) + 1 if title else 0
+        time = ""
+        if with_time:
+            time = f" {datetime.now().strftime('%H:%M:%S')} ──"
+        self.console.print(
+            " ─"
+            + title
+            + ("─" * (self.console.width - title_length - len(time) - 3))
+            + time
+            + " ",
+            style=RICH_STYLE_BLUE,
+        )
+
     def display_debug_info(self, debug_info):
         """Display debug information."""
         self.console.print(Text("Current messages:", style=RICH_STYLE_YELLOW))
@@ -180,7 +199,7 @@ class DisplayHandlers:
             f"  • ~{result['original_token_count'] - result['consolidated_token_count']} tokens saved"
         )
 
-    def display_loaded_conversation(self, messages, message_handler):
+    def display_loaded_conversation(self, messages: List, default_agent_name: str):
         """Display all messages from a loaded conversation."""
         last_consolidated_idx = 0
         for i, msg in reversed(list(enumerate(messages))):
@@ -193,12 +212,18 @@ class DisplayHandlers:
             role = msg.get("role")
             if role == "user":
                 content = self._extract_message_content(msg)
+                if content.startswith("<Transfer_Tool>"):
+                    transfer_text = Text("Transfered to ", style=RICH_STYLE_YELLOW)
+                    transfer_text.append(f"{msg.get('agent', 'unknown')} agent")
+                    self.display_message(transfer_text)
+                    continue
                 self.display_user_message(content)
             elif role == "assistant":
-                agent_name = msg.get("agent") or message_handler.agent.name
+                agent_name = msg.get("agent") or default_agent_name
                 content = self._extract_message_content(msg)
                 # Format as markdown for better display
-                self.display_assistant_message(agent_name, content)
+                if content.strip():
+                    self.display_assistant_message(agent_name, content)
                 if "tool_calls" in msg:
                     for tool_call in msg["tool_calls"]:
                         self._ui.tool_display.display_tool_use(tool_call)
@@ -247,7 +272,7 @@ class DisplayHandlers:
             f"Total: {input_tokens + output_tokens:,} | Cost: ${total_cost:.4f} | Total: {session_cost:.4f}",
             style=RICH_STYLE_YELLOW,
         )
-        self.console.print(Panel(token_info))
+        self.console.print(Panel(token_info, box=HORIZONTALS))
         self.display_divider()
 
     def display_added_files(self):
@@ -262,10 +287,6 @@ class DisplayHandlers:
     def print_welcome_message(self, version: str):
         """Print the welcome message for the chat."""
         welcome_messages = Group(
-            Text(
-                "🎮 Welcome to AgentCrew v" + version + " interactive chat!",
-                style=RICH_STYLE_YELLOW_BOLD,
-            ),
             Text("Press Ctrl+C twice to exit.", style=RICH_STYLE_GRAY),
             Text("Type '/exit' or '/quit' to end the session.", style=RICH_STYLE_GRAY),
             Text(
@@ -329,6 +350,18 @@ class DisplayHandlers:
                 "Use '/toggle_session_yolo' to toggle YOLO mode (auto-approval of tool calls) in this session only.",
                 style=RICH_STYLE_YELLOW,
             ),
+            Text(
+                "Use '/list_behaviors' to list all adaptive behaviors (global and project-specific).",
+                style=RICH_STYLE_YELLOW,
+            ),
+            Text(
+                "Use '/update_behavior <scope> <id> <behavior>' to create or update an adaptive behavior (format: 'when..., do...').",
+                style=RICH_STYLE_YELLOW,
+            ),
+            Text(
+                "Use '/delete_behavior <scope> <id>' to delete an adaptive behavior.",
+                style=RICH_STYLE_YELLOW,
+            ),
             Text("Use '/list' to list saved conversations.", style=RICH_STYLE_YELLOW),
             Text(
                 "Use '/load <id>' or '/load <number>' to load a conversation.",
@@ -352,27 +385,31 @@ class DisplayHandlers:
             ),
         )
 
-        self.console.print(Panel(welcome_messages))
+        self.console.print(
+            Panel(
+                welcome_messages,
+                box=SQUARE,
+                title=Text(
+                    "🎮 Welcome to AgentCrew v" + version + " interactive chat!",
+                    style=RICH_STYLE_YELLOW_BOLD,
+                ),
+            )
+        )
         self.display_divider()
 
     def print_prompt_prefix(
         self, agent_name: str, model_name: str, yolo_mode_enabled: bool
     ):
         """Print the prompt prefix with agent and model information."""
-        title = Text(f"\n[{agent_name}", style=RICH_STYLE_RED)
+        title = Text(f"\n [{agent_name}", style=RICH_STYLE_RED)
         title.append(":")
         title.append(f"{model_name}]", style=RICH_STYLE_BLUE)
 
-        title.append(
-            f"      [{datetime.now().strftime('%H:%M:%S')}]",
-            style=RICH_STYLE_GRAY,
-        )
-
         if yolo_mode_enabled:
-            title.append("\n[YOLO mode enabled]", style=RICH_STYLE_YELLOW_BOLD)
+            title.append("\n [YOLO mode enabled]", style=RICH_STYLE_YELLOW_BOLD)
 
         title.append(
-            "\n(Press Enter for new line, Ctrl+S/Alt+Enter to Send, Ctrl+V to paste)\n",
+            f"\n (Press {'Enter' if not self._ui.input_handler.swap_enter else 'Alt+Enter'} for new line, Ctrl+S/{'Enter' if self._ui.input_handler.swap_enter else 'Alt+Enter'} to Send, Ctrl+V to paste)\n",
             style=RICH_STYLE_YELLOW,
         )
         self.console.print(title)
@@ -404,7 +441,7 @@ class DisplayHandlers:
             return "\n".join(result)
 
         content = re.sub(
-            r"(?:```(?:json)?)?\s*<user_context_summary>.*?</user_context_summary>\s*(?:```)?",
+            r"(?:```(?:json)?)?\s*<agent_evaluation>.*?</agent_evaluation>\s*(?:```)?",
             "",
             str(content),
             flags=re.DOTALL | re.IGNORECASE,
