@@ -23,6 +23,7 @@ from .constants import (
     RICH_STYLE_YELLOW_BOLD,
     RICH_STYLE_RED,
     RICH_STYLE_BLUE,
+    PROMPT_CHAR,
 )
 
 from typing import TYPE_CHECKING
@@ -37,6 +38,7 @@ class InputHandler:
     def __init__(
         self,
         console_ui: ConsoleUI,
+        swap_enter: bool = False,
     ):
         """Initialize the input handler."""
         self.console = console_ui.console
@@ -52,6 +54,8 @@ class InputHandler:
         self._current_prompt_session = None
         self._last_ctrl_c_time = 0
         self.is_message_processing = False
+        self.swap_enter = swap_enter
+        self._jumped_user_message = ""
 
         # Set up key bindings
         self.kb = self._setup_key_bindings()
@@ -59,9 +63,11 @@ class InputHandler:
     def _setup_key_bindings(self):
         """Set up key bindings for multiline input."""
         kb = KeyBindings()
+        submit_keys = ("enter",) if self.swap_enter else ("escape", "enter")
+        newline_keys = ("escape", "enter") if self.swap_enter else ("enter",)
 
         @kb.add(Keys.ControlS)
-        @kb.add("escape", "enter")
+        @kb.add(*submit_keys)
         def _(event):
             """Submit on Ctrl+S."""
             if event.current_buffer.text.strip():
@@ -73,10 +79,10 @@ class InputHandler:
                 ):
                     event.current_buffer.validate_and_handle()
 
-        @kb.add(Keys.Enter)
+        @kb.add(*newline_keys)
         def _(event):
             """Insert newline on Enter."""
-            event.current_buffer.insert_text("\n")
+            event.current_buffer.insert_text(f"\n{PROMPT_CHAR}")
 
         @kb.add("escape", "c")  # Alt+C
         def _(event):
@@ -179,25 +185,40 @@ class InputHandler:
                         self.message_handler.agent.get_model(),
                         self.message_handler.tool_manager.get_effective_yolo_mode(),
                     )
-                    prompt = Text("👤 YOU: ", style=RICH_STYLE_BLUE)
-                    self.console.print(prompt, end="")
                     time.sleep(0.2)
                     self.clear_buffer()
+                    prompt = Text(PROMPT_CHAR, style=RICH_STYLE_BLUE)
+                    self.console.print(prompt, end="")
 
         @kb.add(Keys.Backspace)
         def _(event):
             if not event.current_buffer.text:
                 prompt = Text(
-                    "👤 YOU: " if not self.is_message_processing else "",
+                    PROMPT_CHAR if not self.is_message_processing else "",
                     style=RICH_STYLE_BLUE,
                 )
-                self.console.print("", end="\r")
-                self.console.print(prompt, end="")
+                if not self.is_message_processing:
+                    import sys
+
+                    sys.stdout.write("\x1b[1A")  # cursor up one line
+                    sys.stdout.write("\x1b[2K")
+                    sys.stdout.write("\r")
+                    self.display_handlers.print_divider("👤 YOU: ", with_time=True)
+                    self.console.print(prompt, end="")
+                else:
+                    self.console.print("", end="\r")
             else:
-                event.current_buffer.delete_before_cursor()
+                if (
+                    event.current_buffer.text[-(len(PROMPT_CHAR) + 1) :]
+                    == f"\n{PROMPT_CHAR}"
+                ):
+                    event.current_buffer.delete_before_cursor((len(PROMPT_CHAR) + 1))
+                else:
+                    event.current_buffer.delete_before_cursor()
 
         @kb.add(Keys.ControlUp)
         @kb.add(Keys.Escape, Keys.Up)
+        @kb.add(Keys.ControlK)
         def _(event):
             """Navigate to previous history entry."""
             buffer = event.current_buffer
@@ -221,6 +242,7 @@ class InputHandler:
 
         @kb.add(Keys.ControlDown)
         @kb.add(Keys.Escape, Keys.Down)
+        @kb.add(Keys.ControlJ)
         def _(event):
             """Navigate to next history entry if cursor is at last line."""
             buffer = event.current_buffer
@@ -244,7 +266,14 @@ class InputHandler:
     def clear_buffer(self):
         if self._current_prompt_session:
             self._current_prompt_session.app.current_buffer.reset()
-            self._current_prompt_session.message = HTML("<ansiblue>👤 YOU:</ansiblue> ")
+            if self._jumped_user_message:
+                self._current_prompt_session.app.current_buffer.insert_text(
+                    self._jumped_user_message
+                )
+                self._jumped_user_message = ""
+            if not self.is_message_processing:
+                self.display_handlers.print_divider("👤 YOU: ", with_time=True)
+            self._current_prompt_session.message = HTML(PROMPT_CHAR)
             self._current_prompt_session.app.invalidate()
 
     def get_choice_input(self, message: str, values: list[str], default=None) -> str:
@@ -297,21 +326,25 @@ class InputHandler:
                 session = PromptSession(
                     key_bindings=self.kb,
                     completer=ChatCompleter(self.message_handler),
-                    refresh_interval=0.3,
+                    refresh_interval=0.2,
                 )
                 self._current_prompt_session = session
 
+                if not self.is_message_processing:
+                    self.display_handlers.print_divider("👤 YOU: ", with_time=True)
                 prompt_text = (
-                    HTML("<ansiblue>👤 YOU:</ansiblue> ")
-                    if not self.is_message_processing
-                    else ""
+                    HTML(PROMPT_CHAR) if not self.is_message_processing else ""
                 )
                 user_input = session.prompt(prompt_text)
 
+                if not user_input:
+                    continue
+
+                user_input = user_input.replace(f"\n{PROMPT_CHAR}", "\n")
+
                 self.message_handler.history_manager.reset_position()
 
                 self._input_queue.put(user_input)
-                time.sleep(0.4)  # Allow time for input processing
 
             except KeyboardInterrupt:
                 # Handle Ctrl+C in input thread
@@ -359,6 +392,9 @@ class InputHandler:
                     pass
             self._input_thread.join(timeout=1.0)
 
+    def set_current_buffer(self, content: str):
+        self._jumped_user_message = content
+
     def get_user_input(self):
         """
         Get multiline input from the user with support for command history.
@@ -387,11 +423,14 @@ class InputHandler:
         while True:
             try:
                 # Check for input with a short timeout to allow event processing
-                user_input = self._input_queue.get(timeout=0.2)
+                user_input = self._input_queue.get(timeout=0.1)
 
                 # Add None check here
                 if user_input is None:
                     continue
+                self.is_message_processing = True
+
+                self.display_handlers.print_divider()
 
                 if user_input == "__EXIT__":
                     self.console.print(
@@ -417,7 +456,6 @@ class InputHandler:
                     )
                     return ""
                 else:
-                    self.display_handlers.display_divider()
                     return user_input
 
             except queue.Empty:
