@@ -8,15 +8,16 @@ import json
 from typing import Dict
 from rich.console import Group
 from rich.panel import Panel
+from rich.box import HORIZONTALS
 from rich.text import Text
 
 from .constants import (
+    RICH_STYLE_GRAY,
     RICH_STYLE_YELLOW,
     RICH_STYLE_GREEN,
     RICH_STYLE_BLUE,
     RICH_STYLE_RED,
     RICH_STYLE_WHITE,
-    RICH_STYLE_YELLOW_BOLD,
     RICH_STYLE_GREEN_BOLD,
     RICH_STYLE_RED_BOLD,
 )
@@ -54,8 +55,8 @@ class ToolDisplayHandlers:
         tool_texts_group = []
 
         # Display tool header with better formatting
-        header = Text(f"{tool_icon} Tool: ", style=RICH_STYLE_YELLOW)
-        header.append(tool_use["name"], style=RICH_STYLE_YELLOW_BOLD)
+        header = Text(f"{tool_icon} Tool: ", style=RICH_STYLE_GRAY)
+        header.append(tool_use["name"], style=RICH_STYLE_GRAY)
 
         tool_parameters = tool_use.get("input") or tool_use.get("arguments")
         # Format tool input parameters
@@ -90,6 +91,7 @@ class ToolDisplayHandlers:
             Panel(
                 Group(*tool_texts_group),
                 title=header,
+                box=HORIZONTALS,
                 title_align="left",
             )
         )
@@ -124,7 +126,12 @@ class ToolDisplayHandlers:
                 tool_texts_group.append(result_line)
 
         self.console.print(
-            Panel(Group(*tool_texts_group), title=header, title_align="left")
+            Panel(
+                Group(*tool_texts_group),
+                box=HORIZONTALS,
+                title=header,
+                title_align="left",
+            )
         )
 
     def display_tool_error(self, data: Dict):
@@ -145,6 +152,7 @@ class ToolDisplayHandlers:
         self.console.print(
             Panel(
                 Group(*tool_texts_group),
+                box=HORIZONTALS,
                 title=header,
                 title_align="left",
                 border_style=RICH_STYLE_RED,
