@@ -10,6 +10,7 @@ import threading
 import itertools
 import random
 from rich.live import Live
+from rich.box import HORIZONTALS
 from rich.markdown import Markdown
 from rich.panel import Panel
 
@@ -30,12 +31,14 @@ class UIEffects:
         self.live = None
         self._loading_stop_event = None
         self._loading_thread = None
-        self._visible_buffer = 0
+        self._visible_buffer = -1
+        self._tracking_buffer = 0
         self.message_handler = console_ui.message_handler
+        self.spinner = itertools.cycle(["⣾", "⣽", "⣻", "⢿", "⡿", "⣟", "⣯", "⣷"])
+        self.updated_text = ""
 
     def _loading_animation(self, stop_event):
         """Display a loading animation in the terminal."""
-        spinner = itertools.cycle(["⣾", "⣽", "⣻", "⢿", "⡿", "⣟", "⣯", "⣷"])
         fun_words = [
             "Pondering",
             "Cogitating",
@@ -60,10 +63,14 @@ class UIEffects:
             "", console=self.console, auto_refresh=True, refresh_per_second=10
         ) as live:
             while not stop_event.is_set():
-                live.update(f"{fun_word} {next(spinner)}")
+                live.update(f"{fun_word} {next(self.spinner)}")
                 time.sleep(0.1)  # Control animation speed
             live.update("")  # Clear the live display when done
             live.stop()  # Stop the live display
+            import sys
+
+            sys.stdout.write("\x1b[1A")  # cursor up one line
+            sys.stdout.write("\x1b[2K")
 
     def start_loading_animation(self):
         """Start the loading animation."""
@@ -93,37 +100,52 @@ class UIEffects:
 
         header = Text(f"🤖 {agent_name.upper()}:", style=RICH_STYLE_GREEN_BOLD)
 
-        live_panel = Panel("", title=header, border_style=RICH_STYLE_GREEN)
+        live_panel = Panel(
+            "", title=header, box=HORIZONTALS, border_style=RICH_STYLE_GREEN
+        )
 
         self.live = Live(
             live_panel,
-            refresh_per_second=60,
             console=self.console,
+            auto_refresh=False,
             vertical_overflow="crop",
         )
         self.live.start()
 
     def scroll_live_display(self, direction: str):
         speed = 10
+        if self._visible_buffer == -1:
+            self._visible_buffer = self._tracking_buffer
         if direction == "up":
             self._visible_buffer = max(0, self._visible_buffer - speed)
         elif direction == "down":
             self._visible_buffer += speed
+        if self.live:
+            self.update_live_display(self.updated_text)
 
     def update_live_display(self, chunk: str):
         """Update the live display with a new chunk of the response."""
         if not self.live:
             self.start_streaming_response(self.message_handler.agent.name)
 
-        updated_text = chunk
+        if chunk != self.updated_text:
+            self.updated_text = chunk
 
         # Only show the last part that fits in the console
-        lines = updated_text.split("\n")
-        height_limit = (
-            self.console.size.height - 5
-        )  # leave some space for other elements
+        lines = self.updated_text.split("\n")
+        height_limit = int(self.console.size.height * 0.9)
         if len(lines) > height_limit:
-            lines = lines[self._visible_buffer : self._visible_buffer + height_limit]
+            if (
+                self._visible_buffer == -1
+                or self._visible_buffer > len(lines) - height_limit
+            ):
+                self._tracking_buffer = len(lines) - height_limit
+                self._visible_buffer = -1
+                lines = lines[-height_limit:]
+            else:
+                lines = lines[
+                    self._visible_buffer : self._visible_buffer + height_limit
+                ]
 
         if self.live:
             from .constants import RICH_STYLE_GREEN_BOLD
@@ -133,19 +155,27 @@ class UIEffects:
                 f"🤖 {self.message_handler.agent.name.upper()}:",
                 style=RICH_STYLE_GREEN_BOLD,
             )
-            subtitle = Text("(Use Ctrl+U/Ctrl+D to scroll)", style=RICH_STYLE_GRAY)
+            subtitle = Text(
+                f"{next(self.spinner)}(Use Ctrl+U/Ctrl+D to scroll)",
+                style=RICH_STYLE_GRAY,
+            )
             live_panel = Panel(
                 Markdown("\n".join(lines), code_theme=CODE_THEME),
                 title=header,
+                box=HORIZONTALS,
                 subtitle=subtitle,
                 title_align="left",
+                expand=False,
+                height=min(height_limit, len(lines)),
                 border_style=RICH_STYLE_GREEN,
             )
-            self.live.update(live_panel)
+            self.live.update(live_panel, refresh=True)
 
     def finish_live_update(self):
         """Stop the live update display."""
-        self._visible_buffer = 0
+        self._visible_buffer = -1
+        self._tracking_buffer = 0
+        self.updated_text = ""
         if self.live:
             self.console.print(self.live.get_renderable())
             self.live.update("")
@@ -157,7 +187,9 @@ class UIEffects:
         from .constants import RICH_STYLE_GREEN_BOLD
         from rich.text import Text
 
-        self._visible_buffer = 0
+        self._visible_buffer = -1
+        self._tracking_buffer = 0
+        self.updated_text = ""
 
         if self.live:
             self.live.update(Text("", end=""))
@@ -177,6 +209,7 @@ class UIEffects:
         assistant_panel = Panel(
             Markdown(markdown_formatted_response, code_theme=CODE_THEME),
             title=header,
+            box=HORIZONTALS,
             title_align="left",
             border_style=RICH_STYLE_GREEN,
         )
