@@ -384,6 +384,7 @@ class GoogleAINativeService(BaseLLMService):
         """
         # Convert messages to Google GenAI format
         google_messages = self._convert_internal_format(messages)
+        full_model_id = f"{self._provider_name}/{self.model}"
 
         # Create configuration with tools
         config = types.GenerateContentConfig(
@@ -392,13 +393,26 @@ class GoogleAINativeService(BaseLLMService):
             top_p=0.95,
         )
 
+        forced_sample_params = ModelRegistry.get_model_sample_params(full_model_id)
+        if forced_sample_params:
+            if forced_sample_params.temperature is not None:
+                config.temperature = forced_sample_params.temperature
+            if forced_sample_params.top_p is not None:
+                config.top_p = forced_sample_params.top_p
+            if forced_sample_params.top_k is not None:
+                config.top_k = forced_sample_params.top_k
+            if forced_sample_params.frequency_penalty is not None:
+                config.frequency_penalty = forced_sample_params.frequency_penalty
+            if forced_sample_params.presence_penalty is not None:
+                config.presence_penalty = forced_sample_params.presence_penalty
+
         # Add system instruction if available
         if self.system_prompt:
             config.system_instruction = self.system_prompt
 
         # Add tools if available
         if self.tools and "tool_use" in ModelRegistry.get_model_capabilities(
-            f"{self._provider_name}/{self.model}"
+            full_model_id
         ):
             config.tools = self.tools
 
@@ -407,6 +421,14 @@ class GoogleAINativeService(BaseLLMService):
                 thinking_budget=self.thinking_budget
             )
 
+        if (
+            "structured_output" in ModelRegistry.get_model_capabilities(full_model_id)
+            and self.structured_output
+        ):
+            config.response_mime_type = "application/json"
+            config.response_json_schema = self.structured_output
+            config.tools = None
+
         # Get the stream generator
         stream_generator = self.client.models.generate_content_stream(
             model=self.model, contents=google_messages, config=config
