@@ -1,26 +1,16 @@
-from .types import Model
+from .types import Model, SampleParam
 
 _ANTHROPIC_MODELS = [
     Model(
-        id="claude-opus-4-20250514",
+        id="claude-opus-4-1",
         provider="claude",
-        name="Claude 4 Opus",
+        name="Claude 4.1 Opus",
         description="Anthropic's most capable and intelligent model yet. Claude Opus 4 sets new standards in complex reasoning and advanced coding",
         capabilities=["thinking", "tool_use", "vision", "stream"],
         default=False,
         input_token_price_1m=15.0,
         output_token_price_1m=75.0,
     ),
-    Model(
-        id="claude-sonnet-4-20250514",
-        provider="claude",
-        name="Claude 4 Sonnet",
-        description="Anthropic's high-performance model with exceptional reasoning and efficiency",
-        capabilities=["thinking", "tool_use", "vision", "stream"],
-        default=False,
-        input_token_price_1m=3.0,
-        output_token_price_1m=15.0,
-    ),
     Model(
         id="claude-sonnet-4-5",
         provider="claude",
@@ -32,30 +22,11 @@ _ANTHROPIC_MODELS = [
         output_token_price_1m=15.0,
     ),
     Model(
-        id="claude-3-7-sonnet-latest",
+        id="claude-haiku-4-5",
         provider="claude",
-        name="Claude 3.7 Sonnet",
-        description="Anthropic's most powerful model with advanced reasoning",
-        capabilities=["thinking", "tool_use", "vision", "stream"],
-        default=True,
-        input_token_price_1m=3.0,
-        output_token_price_1m=15.0,
-    ),
-    Model(
-        id="claude-3-5-sonnet-latest",
-        provider="claude",
-        name="Claude 3.5 Sonnet",
-        description="Anthropic's Claude 3.5 Sonnet model - balanced performance and capabilities",
-        capabilities=["tool_use", "vision", "stream"],
-        input_token_price_1m=3.0,
-        output_token_price_1m=15.0,
-    ),
-    Model(
-        id="claude-3-5-haiku-latest",
-        provider="claude",
-        name="Claude 3.5 Haiku",
+        name="Claude 4.5 Haiku",
         description="Anthropic's fastest model",
-        capabilities=["tool_use", "vision", "stream"],
+        capabilities=["tool_use", "vision", "stream", "thinking"],
         input_token_price_1m=0.8,
         output_token_price_1m=4.0,
     ),
@@ -67,7 +38,7 @@ _OPENAI_MODELS = [
         provider="openai",
         name="GPT-5",
         description="GPT-5 is our flagship model for coding, reasoning, and agentic tasks across domains",
-        capabilities=["tool_use", "vision", "thinking", "stream"],
+        capabilities=["tool_use", "vision", "thinking", "stream", "structured_output"],
         input_token_price_1m=1.25,
         output_token_price_1m=10,
         default=True,
@@ -77,37 +48,62 @@ _OPENAI_MODELS = [
         provider="openai",
         name="GPT-5 Codex",
         description="GPT-5-Codex is a version of GPT-5 optimized for agentic coding tasks in Codex or similar environments",
-        capabilities=["tool_use", "vision", "thinking", "stream"],
+        capabilities=["tool_use", "vision", "thinking", "stream", "structured_output"],
         input_token_price_1m=1.25,
         output_token_price_1m=10,
-        default=True,
+    ),
+    Model(
+        id="gpt-5.1",
+        provider="openai",
+        name="GPT-5.1",
+        description="GPT-5 is our flagship model for coding, reasoning, and agentic tasks across domains",
+        capabilities=["tool_use", "vision", "thinking", "stream", "structured_output"],
+        max_context_token=400_000,
+        input_token_price_1m=1.25,
+        output_token_price_1m=10,
+    ),
+    Model(
+        id="gpt-5.1-codex",
+        provider="openai",
+        name="GPT-5.1 Codex",
+        description="GPT-5-Codex is a version of GPT-5 optimized for agentic coding tasks in Codex or similar environments",
+        capabilities=["tool_use", "vision", "thinking", "stream", "structured_output"],
+        input_token_price_1m=1.25,
+        output_token_price_1m=10,
+    ),
+    Model(
+        id="gpt-5.1-codex-mini",
+        provider="openai",
+        name="GPT-5.1 Codex Mini",
+        description="GPT-5-Codex is a version of GPT-5 optimized for agentic coding tasks in Codex or similar environments",
+        capabilities=["tool_use", "vision", "thinking", "stream", "structured_output"],
+        input_token_price_1m=0.25,
+        output_token_price_1m=2.0,
     ),
     Model(
         id="gpt-4.1-mini",
         provider="openai",
         name="GPT-4.1 Mini",
         description="small, quick GPT model",
-        capabilities=["tool_use", "vision", "stream"],
+        capabilities=["tool_use", "vision", "stream", "structured_output"],
         input_token_price_1m=0.15,
         output_token_price_1m=0.6,
-        default=True,
     ),
     Model(
         id="gpt-4.1",
         provider="openai",
         name="GPT-4.1",
         description="Flagship model for complex tasks. It is well suited for problem solving across domains",
-        capabilities=["tool_use", "vision", "stream"],
+        capabilities=["tool_use", "vision", "stream", "structured_output"],
         input_token_price_1m=2,
         output_token_price_1m=8,
-        default=True,
     ),
     Model(
         id="o3-mini",
         provider="openai",
         name="GPT o3 mini",
         description="Fast, flexible, intelligent reasoning model",
-        capabilities=["thinking", "stream"],
+        capabilities=["thinking", "stream", "structured_output"],
         input_token_price_1m=1.1,
         output_token_price_1m=4.4,
     ),
@@ -116,7 +112,7 @@ _OPENAI_MODELS = [
         provider="openai",
         name="GPT o4 mini",
         description="o4-mini is our latest small o-series model. It's optimized for fast, effective reasoning with exceptionally efficient performance in coding and visual tasks.",
-        capabilities=["thinking", "tool_use", "vision", "stream"],
+        capabilities=["thinking", "tool_use", "vision", "stream", "structured_output"],
         input_token_price_1m=1.1,
         output_token_price_1m=4.4,
     ),
@@ -125,7 +121,7 @@ _OPENAI_MODELS = [
         provider="openai",
         name="GPT o3",
         description="a well-rounded and powerful model across domains. It sets a new standard for math, science, coding, and visual reasoning tasks. ",
-        capabilities=["thinking", "tool_use", "vision", "stream"],
+        capabilities=["thinking", "tool_use", "vision", "stream", "structured_output"],
         input_token_price_1m=2.0,
         output_token_price_1m=8.0,
     ),
@@ -201,20 +197,22 @@ _GROQ_MODELS = [
 
 _GOOGLE_MODELS = [
     Model(
-        id="gemini-2.5-flash-lite-preview-06-17",
+        id="gemini-2.5-flash-lite",
         provider="google",
         name="Gemini 2.5 Lite",
         description="Gemini 2.0 Flash Lite is low latancy, balanced language model from Google, designed for both text and visual inputs.",
-        capabilities=["tool_use", "vision"],
+        max_context_token=1_000_000,
+        capabilities=["tool_use", "vision", "structured_output"],
         input_token_price_1m=0.1,
         output_token_price_1m=0.4,
     ),
     Model(
         id="gemini-2.5-flash",
         provider="google",
+        max_context_token=1_000_000,
         name="Gemini 2.5 Flash ",
         description="Gemini 2.5 Flash is Google's first fully hybrid reasoning AI model, designed for high speed and cost-efficiency, allowing developers to toggle advanced reasoning on or off as needed.",
-        capabilities=["tool_use", "vision", "thinking"],
+        capabilities=["tool_use", "vision", "thinking", "structured_output"],
         input_token_price_1m=0.3,
         output_token_price_1m=2.5,
         default=True,
@@ -223,29 +221,32 @@ _GOOGLE_MODELS = [
         id="gemini-2.5-pro",
         provider="google",
         name="Gemini 2.5 Pro Thinking",
+        max_context_token=1_000_000,
         description="Gemini 2.5 Pro with thinking",
-        capabilities=["tool_use", "thinking", "vision"],
+        capabilities=["tool_use", "thinking", "vision", "structured_output"],
         input_token_price_1m=1.25,
         output_token_price_1m=10,
     ),
+    Model(
+        id="gemini-3-pro-preview",
+        provider="google",
+        name="Gemini 3 Pro",
+        max_context_token=1_000_000,
+        description="Google's most intelligent model family to date, built on a foundation of state-of-the-art reasoning",
+        capabilities=["tool_use", "thinking", "vision", "structured_output"],
+        force_sample_params=SampleParam(temperature=1.0),
+        input_token_price_1m=2,
+        output_token_price_1m=12,
+    ),
 ]
 
 _DEEPINFRA_MODELS = [
-    Model(
-        id="meta-llama/Llama-3.3-70B-Instruct",
-        provider="deepinfra",
-        name="Llama 3.3 70B Instruct",
-        description="Llama 3.3-70B is a multilingual LLM trained on a massive dataset of 15 trillion tokens, fine-tuned for instruction-following and conversational dialogue",
-        capabilities=["tool_use", "text-generation", "stream"],
-        input_token_price_1m=0.23,
-        output_token_price_1m=0.40,
-    ),
     Model(
         id="google/gemma-3-27b-it",
         provider="deepinfra",
         name="Gemma 3 27B",
         description="Gemma is a family of lightweight, state-of-the-art open models from Google, built from the same research and technology used to create the Gemini models",
-        capabilities=["text-generation", "tool_use", "stream"],
+        capabilities=["tool_use", "stream", "structured_output"],
         input_token_price_1m=0.1,
         output_token_price_1m=0.2,
     ),
@@ -254,7 +255,7 @@ _DEEPINFRA_MODELS = [
         provider="deepinfra",
         name="GPT-OSS 120B",
         description="gpt-oss-120b is an open-weight, 117B-parameter Mixture-of-Experts (MoE) language model from OpenAI designed for high-reasoning, agentic, and general-purpose production use cases",
-        capabilities=["text-generation", "tool_use", "stream", "thinking"],
+        capabilities=["tool_use", "stream", "thinking"],
         input_token_price_1m=0.09,
         output_token_price_1m=0.45,
     ),
@@ -263,16 +264,34 @@ _DEEPINFRA_MODELS = [
         provider="deepinfra",
         name="Qwen 3 Coder",
         description="Qwen3-Coder-480B-A35B-Instruct is the Qwen3's most agentic code model",
-        capabilities=["text-generation", "tool_use", "stream"],
+        capabilities=["tool_use", "stream", "structured_output"],
+        force_sample_params=SampleParam(
+            temperature=0.7, top_p=0.8, top_k=20, repetition_penalty=1.05
+        ),
         input_token_price_1m=0.4,
         output_token_price_1m=1.6,
     ),
     Model(
-        id="Qwen/Qwen3-235B-A22B",
+        id="Qwen/Qwen3-Next-80B-A3B-Instruct",
+        provider="deepinfra",
+        name="Qwen 3 Coder",
+        description="Qwen3-Coder-480B-A35B-Instruct is the Qwen3's most agentic code model",
+        capabilities=["tool_use", "stream", "structured_output"],
+        force_sample_params=SampleParam(
+            temperature=0.7, top_p=0.8, top_k=20, min_p=0.0
+        ),
+        input_token_price_1m=0.14,
+        output_token_price_1m=1.1,
+    ),
+    Model(
+        id="Qwen/Qwen3-235B-A22B-Thinking-2507",
         provider="deepinfra",
         name="Qwen 3 MoE 235B-22B",
         description="Qwen3 is the latest generation of large language models in Qwen series, offering a comprehensive suite of dense and mixture-of-experts (MoE) models",
-        capabilities=["text-generation", "tool_use", "thinking", "stream"],
+        capabilities=["tool_use", "thinking", "stream", "structured_output"],
+        force_sample_params=SampleParam(
+            temperature=0.6, top_p=0.95, top_k=20, min_p=0.0
+        ),
         input_token_price_1m=0.2,
         output_token_price_1m=0.6,
     ),
@@ -281,7 +300,8 @@ _DEEPINFRA_MODELS = [
         provider="deepinfra",
         name="Zai GLM-4.6",
         description="The GLM-4.6 series models are foundation models designed for intelligent agents",
-        capabilities=["text-generation", "tool_use", "stream"],
+        force_sample_params=SampleParam(temperature=1, top_p=0.95, top_k=40),
+        capabilities=["tool_use", "stream", "structured_output"],
         input_token_price_1m=0.6,
         output_token_price_1m=2.0,
     ),
@@ -290,25 +310,19 @@ _DEEPINFRA_MODELS = [
         provider="deepinfra",
         name="Qwen 3 32B",
         description="Qwen3 is the latest generation of large language models in Qwen series, offering a comprehensive suite of dense and mixture-of-experts (MoE) models",
-        capabilities=["text-generation", "tool_use", "stream"],
+        capabilities=["tool_use", "stream", "structured_output"],
+        force_sample_params=SampleParam(
+            temperature=0.6, top_p=0.95, top_k=20, min_p=0.0
+        ),
         input_token_price_1m=0.1,
         output_token_price_1m=0.3,
     ),
     Model(
-        id="Qwen/QwQ-32B",
-        provider="deepinfra",
-        name="Qwen QwQ 32B",
-        description="QwQ is the reasoning model of the Qwen series",
-        capabilities=["text-generation", "stream", "thinking"],
-        input_token_price_1m=0.15,
-        output_token_price_1m=0.2,
-    ),
-    Model(
-        id="deepseek-ai/DeepSeek-V3.1",
+        id="deepseek-ai/DeepSeek-V3.1-Terminus",
         provider="deepinfra",
         name="DeepSeek V3.1",
         description="DeepSeek-V3.1 is post-trained on the top of DeepSeek-V3.1-Base, which is built upon the original V3 base checkpoint through a two-phase long context extension approach",
-        capabilities=["text-generation", "tool_use", "stream"],
+        capabilities=["tool_use", "stream", "structured_output"],
         input_token_price_1m=0.3,
         output_token_price_1m=1.0,
     ),
@@ -317,18 +331,20 @@ _DEEPINFRA_MODELS = [
         provider="deepinfra",
         name="DeepSeek R1 0528",
         description="The DeepSeek R1 model has undergone a minor version upgrade, with the current version being DeepSeek-R1-0528.",
-        capabilities=["text-generation", "tool_use", "thinking", "stream"],
+        capabilities=["tool_use", "thinking", "stream", "structured_output"],
+        force_sample_params=SampleParam(temperature=0.6),
         input_token_price_1m=0.5,
         output_token_price_1m=2.18,
     ),
     Model(
-        id="moonshotai/Kimi-K2-Instruct",
+        id="moonshotai/Kimi-K2-Instruct-0905",
         provider="deepinfra",
         name="Kimi K2 Instruct",
         description="Kimi K2 is a large-scale Mixture-of-Experts (MoE) language model developed by Moonshot AI, featuring 1 trillion total parameters with 32 billion active per forward pass",
-        capabilities=["text-generation", "tool_use", "stream"],
-        input_token_price_1m=0.55,
-        output_token_price_1m=2.22,
+        capabilities=["tool_use", "stream", "structured_output"],
+        force_sample_params=SampleParam(temperature=0.6),
+        input_token_price_1m=0.5,
+        output_token_price_1m=2.0,
     ),
 ]
 _GITHUB_COPILOT_MODELS = [
@@ -352,12 +368,23 @@ _GITHUB_COPILOT_MODELS = [
         input_token_price_1m=0.0,
         output_token_price_1m=0.0,
     ),
+    Model(
+        id="gemini-3-pro-preview",
+        provider="github_copilot",
+        name="Gemini 3 Pro",
+        description="",
+        capabilities=["tool_use", "vision", "stream"],
+        default=False,
+        input_token_price_1m=0.0,
+        force_sample_params=SampleParam(temperature=1.0),
+        output_token_price_1m=0.0,
+    ),
     Model(
         id="gpt-4.1",
         provider="github_copilot",
         name="GPT 4.1",
         description="",
-        capabilities=["tool_use", "vision", "stream"],
+        capabilities=["tool_use", "vision", "stream", "structured_output"],
         default=False,
         input_token_price_1m=0.0,
         output_token_price_1m=0.0,
@@ -367,7 +394,7 @@ _GITHUB_COPILOT_MODELS = [
         provider="github_copilot",
         name="Grok Code Fast 1",
         description="",
-        capabilities=["tool_use", "vision", "stream"],
+        capabilities=["tool_use", "vision", "stream", "structured_output"],
         default=False,
         input_token_price_1m=0.0,
         output_token_price_1m=0.0,
@@ -387,7 +414,7 @@ _GITHUB_COPILOT_MODELS = [
         provider="github_copilot",
         name="GPT 5",
         description="",
-        capabilities=["tool_use", "vision", "stream"],
+        capabilities=["tool_use", "vision", "stream", "structured_output"],
         default=False,
         input_token_price_1m=0.0,
         output_token_price_1m=0.0,
@@ -397,7 +424,7 @@ _GITHUB_COPILOT_MODELS = [
         provider="copilot_response",
         name="GPT 5 Codex",
         description="",
-        capabilities=["tool_use", "vision", "stream"],
+        capabilities=["tool_use", "vision", "stream", "structured_output"],
         default=False,
         input_token_price_1m=0.0,
         output_token_price_1m=0.0,
@@ -408,27 +435,62 @@ _GITHUB_COPILOT_MODELS = [
         provider="github_copilot",
         name="GPT 5 mini",
         description="",
-        capabilities=["tool_use", "vision", "stream", "thinking"],
-        default=True,
+        capabilities=["tool_use", "vision", "stream", "thinking", "structured_output"],
+        default=False,
         input_token_price_1m=0.0,
         output_token_price_1m=0.0,
     ),
     Model(
-        id="o1",
+        id="gpt-5.1",
         provider="github_copilot",
-        name="o1",
+        name="GPT 5.1",
         description="",
-        capabilities=["tool_use", "thinking", "vision", "stream"],
+        capabilities=["tool_use", "vision", "stream", "structured_output"],
+        max_context_token=264_000,
         default=False,
         input_token_price_1m=0.0,
         output_token_price_1m=0.0,
     ),
+    Model(
+        id="gpt-5.1-codex",
+        provider="copilot_response",
+        name="GPT 5 Codex",
+        description="",
+        capabilities=["tool_use", "vision", "stream", "structured_output"],
+        max_context_token=400_000,
+        default=False,
+        input_token_price_1m=0.0,
+        output_token_price_1m=0.0,
+        endpoint="response",
+    ),
+    Model(
+        id="gpt-5.1-codex-mini",
+        provider="github_copilot",
+        name="GPT 5 mini",
+        description="",
+        capabilities=["tool_use", "vision", "stream", "thinking", "structured_output"],
+        default=False,
+        input_token_price_1m=0.0,
+        output_token_price_1m=0.0,
+        endpoint="response",
+    ),
+    Model(
+        id="oswe-vscode-prime",
+        provider="github_copilot",
+        name="Raptor mini",
+        max_context_token=200_000,
+        description="",
+        capabilities=["tool_use", "vision", "stream", "structured_output"],
+        default=True,
+        input_token_price_1m=0.0,
+        output_token_price_1m=0.0,
+    ),
     Model(
         id="claude-sonnet-4",
         provider="github_copilot",
         name="Claude Sonnet 4",
         description="",
-        capabilities=["tool_use", "vision", "stream"],
+        capabilities=["tool_use", "vision", "stream", "thinking"],
         default=False,
         input_token_price_1m=0.0,
         output_token_price_1m=0.0,
@@ -444,11 +506,11 @@ _GITHUB_COPILOT_MODELS = [
         output_token_price_1m=0.0,
     ),
     Model(
-        id="claude-opus-4.1",
+        id="claude-opus-41",
         provider="github_copilot",
         name="Claude Opus 4.1 (Preview)",
         description="",
-        capabilities=["tool_use", "vision", "stream", "thinking"],
+        capabilities=["tool_use", "vision", "stream"],
         default=False,
         input_token_price_1m=0.0,
         output_token_price_1m=0.0,
