@@ -8,31 +8,21 @@ from .base_service import BaseMemoryService
 def get_memory_forget_tool_definition(provider="claude") -> Dict[str, Any]:
     """Optimized memory forgetting tool definition."""
 
-    tool_description = """Removes memories related to specific topics or IDs from storage.
+    tool_description = """Removes memories using IDs from memory bank.
 
 Use for clearing outdated information, removing sensitive data, resolving conflicting memories, or correcting errors.
 
-Be specific with topics to avoid over-deletion. Use IDs for precise removal when available.
-Use date filters to limit scope whenever posible, Eg: yesterday: from_date = current_date - 1"""
+Search for memories need to remote, use date filters to limit scope whenever posible, Eg: yesterday: from_date = current_date - 1 and use IDs for precise removal."""
 
     tool_arguments = {
-        "topic": {
-            "type": "string",
+        "ids": {
+            "type": "array",
             "description": "Keywords describing what to forget. Use specific terms like 'project alpha 2024 credentials' or 'outdated api documentation v1'. Avoid broad terms like 'user' or 'project'.",
-        },
-        "from_date": {
-            "type": "string",
-            "format": "date",
-            "description": "Filter removing memories from this date (YYYY-MM-DD). Optional.",
-        },
-        "to_date": {
-            "type": "string",
-            "format": "date",
-            "description": "Filter removing memories til this date (YYYY-MM-DD). Optional.",
+            "items": {"type": "string"},
         },
     }
 
-    tool_required = ["topic"]
+    tool_required = ["ids"]
 
     if provider == "claude":
         return {
@@ -63,41 +53,21 @@ def get_memory_forget_tool_handler(memory_service: BaseMemoryService) -> Callabl
     """Optimized memory forgetting handler with concise feedback."""
 
     def handle_memory_forget(**params) -> str:
-        topic = params.get("topic", "").strip()
-
-        from_date = params.get("from_date", None)
-        to_date = params.get("to_date", None)
+        ids = params.get("ids", "").strip()
 
         # Use provided agent_name or fallback to current agent
         current_agent = AgentManager.get_instance().get_current_agent()
         agent_name = current_agent.name if current_agent else "None"
 
-        # Topic-based removal
-        if not topic:
-            return "❌ Topic required for memory removal."
-
-        # Prevent overly broad deletion
-        risky_terms = ["all", "everything", "user", "conversation", "memory"]
-        if topic.lower() in risky_terms:
-            return f"⚠️ '{topic}' too broad. Use specific terms to avoid over-deletion."
-
         try:
-            if from_date:
-                from_date = int(dt.strptime(from_date, "%Y-%m-%d").timestamp())
-            if to_date:
-                to_date = int(dt.strptime(to_date, "%Y-%m-%d").timestamp())
-            if from_date and to_date and from_date >= to_date:
-                raise ValueError(
-                    "from_date must be earlier than and not equal to to_date."
-                )
-            result = memory_service.forget_topic(topic, from_date, to_date, agent_name)
+            result = memory_service.forget_ids(ids, agent_name)
             return (
-                f"✅ Removed memories for '{topic}': {result.get('message', 'Success')}"
+                f"Removed memories: {result.get('message', 'Success')}"
                 if result.get("success")
-                else f"⚠️ Removal incomplete: {result.get('message', 'Not found')}"
+                else f"Removal incomplete: {result.get('message', 'Not found')}"
             )
         except Exception as e:
-            return f"❌ Topic removal failed: {str(e)}"
+            return f"Memories removal failed: {str(e)}"
 
     return handle_memory_forget
 
@@ -105,15 +75,15 @@ def get_memory_forget_tool_handler(memory_service: BaseMemoryService) -> Callabl
 def get_memory_retrieve_tool_definition(provider="claude") -> Dict[str, Any]:
     """Optimized memory retrieval tool definition."""
 
-    tool_description = """Retrieves relevant information from conversation history using semantic search.
+    tool_description = """Search relevant information from conversation history using semantic search.
 Use for gathering context, accessing user preferences, finding similar problems, and maintaining conversation continuity. 
-Search with specific, descriptive keywords for better results.
+Search with specific, descriptive queries for better results.
 Use from_date and to_date to filter memories by time whenever posible, Eg: yesterday: from_date = current_date - 1"""
 
     tool_arguments = {
-        "phrases": {
+        "query": {
             "type": "string",
-            "description": "Search a phrases for finding relevant memories. Use specific semantic phrases like 'project alpha database issues' or 'user preferences communication style' rather than single words.",
+            "description": "A searching query for finding relevant memories. Use specific semantic phrases like 'project alpha database issues' or 'user preferences communication style' rather than keywords.",
         },
         "from_date": {
             "type": "string",
@@ -127,11 +97,11 @@ Use from_date and to_date to filter memories by time whenever posible, Eg: yeste
         },
     }
 
-    tool_required = ["phrases"]
+    tool_required = ["query"]
 
     if provider == "claude":
         return {
-            "name": "retrieve_memory",
+            "name": "search_memory",
             "description": tool_description,
             "input_schema": {
                 "type": "object",
@@ -143,7 +113,7 @@ Use from_date and to_date to filter memories by time whenever posible, Eg: yeste
         return {
             "type": "function",
             "function": {
-                "name": "retrieve_memory",
+                "name": "search_memory",
                 "description": tool_description,
                 "parameters": {
                     "type": "object",
@@ -159,16 +129,16 @@ def memory_instruction_prompt():
     return """<Memory_System>
   <Purpose>
     Extremely useful for gathering context through intelligent storage and retrieval of relevant information.
-    Call retrieve_memory when on of retrieval triggers occur to provide better responses.
+    Call search_memory when one of <Memory_Triggers> occur to provide better responses.
   </Purpose>
   <Usage_Guidelines>
-    <Retrieval_Triggers>
+    <Memory_Triggers>
       - When start a new conversation - gather relevant context from user request
       - When current topic changes - Get new topic-related memories context for better responses
       - When User references to past interactions
-    </Retrieval_Triggers>
+    </Memory_Triggers>
     <Search_Strategy>
-      - Use specific, descriptive phrases
+      - Use specific, descriptive queries
       - Combine related concepts with spaces
       - Include temporal indicators when relevant
       - Include time filters when applicable
@@ -177,8 +147,7 @@ def memory_instruction_prompt():
     <Memory_Management>
       - Remove outdated/conflicting information when corrected
       - Clear sensitive data when requested
-      - Use precise topic phrases to avoid over-deletion
-      - Prefer ID-based removal for surgical precision
+      - Search and Use ID-based removal for surgical precision
     </Memory_Management>
   </Usage_Guidelines>
 </Memory_System>"""
@@ -188,16 +157,16 @@ def get_memory_retrieve_tool_handler(memory_service: BaseMemoryService) -> Calla
     """Optimized memory retrieval handler with concise feedback."""
 
     def handle_memory_retrieve(**params) -> str:
-        phrases = params.get("phrases", "").strip()
+        query = params.get("query", "").strip()
         from_date = params.get("from_date", None)
         to_date = params.get("to_date", None)
 
-        if not phrases:
-            raise ValueError("❌ Phrases required for memory search. Try again.")
+        if not query:
+            raise ValueError("Phrases required for memory search. Try again.")
 
-        if len(phrases) < 3:
+        if len(query) < 3:
             raise ValueError(
-                f"⚠️ Search term '{phrases}' too short. Try again with more semantica and descriptive phrases."
+                f"Search term '{query}' too short. Try again with more semantica and descriptive phrases."
             )
 
         # Use provided agent_name or fallback to current agent
@@ -215,17 +184,17 @@ def get_memory_retrieve_tool_handler(memory_service: BaseMemoryService) -> Calla
                 )
 
             result = memory_service.retrieve_memory(
-                phrases, from_date, to_date, agent_name
+                query, from_date, to_date, agent_name
             )
 
             if not result or result.strip() == "":
-                return f"📝 No memories found for '{phrases}'. Try broader phrases or related terms."
+                return f"No memories found for '{query}'. Try broader phrases or related terms."
 
             # Count memories for user feedback
-            return f"📚 Found relevant memories:\n\n{result}"
+            return f"Found relevant memories:\n\n{result}"
 
         except Exception as e:
-            return f"❌ Memory search failed: {str(e)}"
+            return f"Memory search failed: {str(e)}"
 
     return handle_memory_retrieve
 
@@ -251,8 +220,7 @@ All behaviors must follow 'when..., [action]...' format for automatic activation
         "scope": {
             "type": "string",
             "enum": ["global", "project"],
-            "default": "global",
-            "description": "Scope of the behavior. 'global' for all interactions, 'project' for current project only. Default is 'global'. Optional.",
+            "description": "Scope of the behavior. 'global' apply for all conversations, 'project' applys for current project only. Use project scope when behavior is project-specific, use global if behavior is general.",
         },
     }
 
@@ -260,7 +228,7 @@ All behaviors must follow 'when..., [action]...' format for automatic activation
 
     if provider == "claude":
         return {
-            "name": "adapt",
+            "name": "adapt_behavior",
             "description": tool_description,
             "input_schema": {
                 "type": "object",
@@ -272,7 +240,7 @@ All behaviors must follow 'when..., [action]...' format for automatic activation
         return {
             "type": "function",
             "function": {
-                "name": "adapt",
+                "name": "adapt_behavior",
                 "description": tool_description,
                 "parameters": {
                     "type": "object",
@@ -292,32 +260,32 @@ def get_adapt_tool_handler(persistence_service: Any) -> Callable:
         scope = params.get("scope", "global").strip().lower()
 
         if not behavior_id:
-            return "❌ Behavior ID required (e.g., 'communication_style_technical')."
+            return "Behavior ID required (e.g., 'communication_style_technical')."
 
         if not behavior:
-            return "❌ Behavior description required in 'when...do...' format."
+            return "Behavior description required in 'when...do...' format."
 
         # Validate format
         behavior_lower = behavior.lower()
         if not behavior_lower.startswith("when "):
-            return "❌ Use format: 'when [condition], [action]'"
+            return "Use format: 'when [condition], [action]'"
 
         current_agent = AgentManager.get_instance().get_current_agent()
         agent_name = current_agent.name if current_agent else "default"
 
         try:
             success = persistence_service.store_adaptive_behavior(
-                agent_name, behavior_id, behavior, scope == "local"
+                agent_name, behavior_id, behavior, scope == "project"
             )
             return (
-                f"✅ Stored behavior '{behavior_id}': {behavior}"
+                f"Stored behavior '{behavior_id}': {behavior}"
                 if success
-                else "⚠️ Storage completed but may need verification."
+                else "Storage completed but may need verification."
             )
         except ValueError as e:
-            return f"❌ Invalid format: {str(e)}"
+            return f"Invalid format: {str(e)}"
         except Exception as e:
-            return f"❌ Storage failed: {str(e)}"
+            return f"Storage failed: {str(e)}"
 
     return handle_adapt
 
